import os, strutils, tables
import subcommands/help, subcommands/init
import handlers/initialRunHandler
import lib/styledOut

type
    CommandHandler = proc(args: seq[string])

var commandRegistry = initTable[string, CommandHandler]()

proc registerCommand(name: string, handler: CommandHandler) =
    commandRegistry[name] = handler

proc helpWrapper(args: seq[string]) =
    let helpMsg = if args.len > 0: args[0] else: "main"
    help.displayHelp(helpMsg, args)

proc processCommands(args: seq[string]) =
    if args.len > 0:
        let cmd = args[0].toLower()
        let subArgs = args[1..^1]
        if cmd in commandRegistry:
            commandRegistry[cmd](subArgs)
        else:
            echo "Unknown command: '", cmd, "'. Use 'help' for available commands."
    else:
        commandRegistry["init"](@[])

proc colorDebug() =
    styledPrintln("This is an info message.", info)
    styledPrintln("This is a warning message.", warning)
    styledPrintln("This is an error message.", error)
    styledPrintln("This is a success message.", success)
    styledPrint("This is a debug message.", debug)

# Register commands
registerCommand("help", helpWrapper)
registerCommand("init", init.init)

proc main() =
    initialRunHandler.initialSetup() # Initialise the program on first run
    let args = commandLineParams()
    processCommands(args)

when isMainModule:
    main()
