# src/commands/help.nim
import terminal

type
    Command = tuple[
        cmd: string,
        desc: string
    ]
    Option = tuple[
        arg: string,
        desc: string
    ]

var commands: seq[Command] = @[
    ("help", "Displays this help message."),
    ("init", "Initialise a project directory with default settings."),
    ("config", "Configure dashinit settings and preferences."),
]

var options: seq[Option] = @[
    ("-h, --help", "Displays this help message.")
]

proc displayHelp*(helpMsg: string, args: seq[string] = @[]) =
    case helpMsg
    of "init":
        var initOptions: seq[Option] = @[
            ("-h, --help", "Displays this help message."),
            ("-g, --git", "Initialises a git repository."),
            ("-v\t", "Verbose output.")
        ]

        echo "dashinit - a powerful templating tool"

        styledEcho "Subcommand: ", styleBright, "init"

        echo "\nUsage:"
        styledEcho styleBright, "   dashinit", resetStyle, " [subcommand] [arguments]"

        echo "\nOptions:"
        for option in initOptions:
            styledEcho "   ", styleBright, option.arg, resetStyle, "  \t", option.desc

        echo "\nExamples:"
        echo "   ", "dashinit", "\t\t\t", "Initialises using default settings."
        echo "   ", "dashinit init", "\t\t", "Initialises using default settings."
        echo "   ", "dashinit init -h", "\t\t", "Shows the help menu for the init subcommand."
        echo "   ", "dashinit init -g", "\t\t", "Initialises a git repository using a template."

    of "template":
        echo "test"

    else:
        echo "dashinit - a powerful templating tool"

        echo "\nUsage:"
        styledEcho styleBright, "   dashinit", resetStyle, " [subcommand] [arguments]"

        echo "\nSubcommands:"
        for command in commands:
            styledEcho "   ", styleBright, command.cmd, resetStyle, "  \t", command.desc

        echo "\nOptions:"
        for option in options:
            styledEcho "   ", styleBright, option.arg, resetStyle, "  \t", option.desc

        echo "\nExamples:"
        echo "   ", "dashinit", "\t\t\t", "Initialises using default settings."
        echo "   ", "dashinit template -h", "\t\t", "Shows the help menu for the template subcommand."