import os, strutils, strformat, times
import ../lib/styledOut, ../lib/utils, ../lib/environment, ../subcommands/help
import parsetoml

# start counting
let startTime = cpuTime()

# # initialise variables
# var verbose = false;

# read config
let config = parsetoml.parseFile(configPath)
# let config = "test"

let confTemplate = config["template"]["default"].getStr("default") # get template from config, otherwise use default
# let confTemplate = "test"
let selectedTemplate = templateBaseDir / confTemplate # set the selected template path (see environment.nim for templateBaseDir)
let currentDir = getCurrentDir()

# subcommand help
type
    Option = tuple[
        arg: string,
        desc: string
    ]

# initialise project function
proc initialiseProject() =
    copyRecursive(selectedTemplate, currentDir)

# Define how to handle configuring a git repo
proc configureGitRepo(gitRemote, gitBranch: string) =
    let setupGitRepo = execShellCmd(&"git remote add origin {gitRemote}")
    let setGitBranch = execShellCmd(&"git branch -m {gitBranch}")
    if setupGitRepo == 0:
        echo &"Successfully added remote {gitRemote}"
    else:
        echo &"Failed to add remote {gitRemote}"
    if setGitBranch == 0:
        echo &"Successfully set branch to {gitBranch}"
    else:
        echo &"Failed to set branch {gitBranch}"

# Main logic
proc init*(args: seq[string]) =
    if "-h" in args or "--help" in args or "help" in args:
        displayHelp("init")
        quit(0)

    var count = 0
    for entry in walkDir(currentDir):
        count += 1
    # If there are files, ask for confirmation, otherwise continue.
    if count > 0:
        styledPrint("This directory is not empty.", warning)
        stdout.write("Continue initialising? [y/N] ")
        var input = stdin.readLine()
        case input.toLower
            of "yes", "y", "z", "j":
                echo "Initialising non-empty directory..."
                initialiseProject()
            else:
                echo "Cancelling..."
                quit 0
    else:
        echo "Initialising..."
        initialiseProject()

    # Handle -g parameter for git repos.
    if "-g" in args or "--git" in args:
        let createdRepo = execShellCmd("git init")
        if createdRepo == 0:
            echo "Successfully initialised local git repository!"
            stdout.write("Would you like to configure it? [Y/n] ")
            var input = stdin.readLine()
            case input.toLower
            of "yes", "y", "z", "j", "":
                stdout.write("Enter the git remote: ")
                let gitRemote = stdin.readLine()
                stdout.write("Enter your desired branch name: ")
                let gitBranch = stdin.readLine()
                echo "Configuring Git repo..."
                configureGitRepo(gitRemote, gitBranch)
            else:
                echo "Skipping repository configuration..."
                echo "Successfully created local git repository!"
        else:
            echo: "Failed creating local git repository."
    let endTime = cpuTime()
    let elapsedTime = (endTime - startTime) * 1000
    let roundElapsedTime = formatFloat(elapsedTime, precision=2)
    echo "Done! (", roundElapsedTime, "ms)"